==> PE70-0307100-linux-glibc2.1.tar.gz: include/image3k.h <==
/* -----------------------------------------------------------------------

   (C) Copyright Marxmeier Software AG 1998-2003. 
   All rights reserved.

   Project:  HP3K API
   File:     image3k.h
   Function: IMAGE3K API
   $Id: image3k.h,v 23.21 2003/07/14 14:42:46 mike Exp $

   If IMAGE3K_STRICT_PROTOTYPES is defined than stricter function
   prototypes are provided (short * vs. void * arguments).

   Edit history:
   15.09.1998, mm  - fixed prototypes
   08.04.1999, mm  - stub prototypes
   14.04.1999, mm  - lwc entry points
   06.02.2002, mm  - add DBTPIINFO
   08.05.2002, mm  - fixed DBERROR prototype
                     added DBLOGON as alias for DBAUTH
   13.09.2002, rhg - DBCALL -> DBCALL3K
   12.07.2003, mm  - added DBVERSION inrinsic

----------------------------------------------------------------------- */

#ifndef IMAGE3K_H
#define IMAGE3K_H

#if defined(__cplusplus)
extern "C" {
#endif

/*
   define ELOQUENCE symbol so EQ aware programs programs can #ifdef
   some stuff ...
*/
#define ELOQUENCE 1


/*
   HP3K intrinsic numbers.
   Not sure if they need to be public, however it should not hurt
   since the symbols are rather unlikely to be used otherwise
*/
enum hp3k_Intrinsic_ID {
   DBOPEN_INTRINSIC_ID    = 401,
   DBINFO_INTRINSIC_ID    = 402,
   DBCLOSE_INTRINSIC_ID   = 403,
   DBFIND_INTRINSIC_ID    = 404,
   DBGET_INTRINSIC_ID     = 405,
   DBUPDATE_INTRINSIC_ID  = 406,
   DBPUT_INTRINSIC_ID     = 407,
   DBDELETE_INTRINSIC_ID  = 408,
   DBLOCK_INTRINSIC_ID    = 409,
   DBUNLOCK_INTRINSIC_ID  = 410,
   DBCONTROL_INTRINSIC_ID = 411,
   DBBEGIN_INTRINSIC_ID   = 412,
   DBEND_INTRINSIC_ID     = 413,
   DBMEMO_INTRINSIC_ID    = 414,
   DBEXPLAIN_INTRINSIC_ID = 418,
   DBERROR_INTRINSIC_ID   = 419,
   DBXBEGIN_INTRINSIC_ID  = 420,
   DBXEND_INTRINSIC_ID    = 421,
   DBXUNDO_INTRINSIC_ID   = 422,
   DBTPIINFO_INTRINSIC_ID = 480
};


/*
   Win32 API calling convention
   default: __stdcall, use -DDBCALL3K=__cdecl compiler directive otherwise
*/
#ifdef _WIN32
#ifndef DBCALL3K
#define DBCALL3K __stdcall
#endif
#else
#ifdef DBCALL3K
#undef DBCALL3K
#endif
#define DBCALL3K /**/
#endif


/*
   IMAGE3K API prototypes
*/

#ifdef IMAGE3K_STRICT_PROTOTYPES
#define HP3K_I16 short
#else
#define HP3K_I16 void
#endif

#if !defined(HP3K_INTERNAL_H) && defined(__HP_cc)
#pragma HP_DEFINED_EXTERNAL dbbegin,dbclose,dbcontrol,dbdelete,dbend 
#pragma HP_DEFINED_EXTERNAL dberror,dbexplain,dbfind,dbget,dbinfo 
#pragma HP_DEFINED_EXTERNAL dblock,dbmemo,dbopen,dbput,dbunlock 
#pragma HP_DEFINED_EXTERNAL dbupdate,dbxbegin,dbxend,dbxundo 
#pragma HP_DEFINED_EXTERNAL dbauth,dblogon,dbversion,dbtpiinfo
#endif

void DBCALL3K dbopen(void *base, const void *pswd, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL3K dbclose(void *base, const void *dset, const HP3K_I16 *modep,
                   HP3K_I16 *status);

void DBCALL3K dbcontrol(const void *base, const void *qualifier,
                     const HP3K_I16 *modep, HP3K_I16 *status);
void DBCALL3K dbinfo(const void *base, const void *qualifier, const HP3K_I16 *modep,
                  HP3K_I16 *status, void *buffer);

void DBCALL3K dbput(const void *base, const void *dset, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *list, void *buffer);
void DBCALL3K dbdelete(const void *base, const void *dset, const HP3K_I16 *modep,
                    HP3K_I16 *status);
void DBCALL3K dbupdate(const void *base, const void *dset, const HP3K_I16 *modep,
                    HP3K_I16 *status, const void *list, const void *buffer);
void DBCALL3K dbget(const void *base, const void *dset, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *list, void *buffer,
                 const void *argument);
void DBCALL3K dbfind(const void *base, const void *dset, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *item, const void *argument);

void DBCALL3K dblock(const void *base, const void *qualifier, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL3K dbunlock(const void *base, const void *qualifier, const HP3K_I16 *modep,
                    HP3K_I16 *status);

void DBCALL3K dbbegin(const void *base, const void *text, const HP3K_I16 *modep,
                   HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbend(const void *base, const void *text, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbmemo(const void *base, const void *text, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *textlenp);

void DBCALL3K dbxbegin(const void *base, const void *text, const HP3K_I16 *modep,
                    HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbxend(const void *base, const void *text, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbxundo(const void *base, const void *text, const HP3K_I16 *modep,
                   HP3K_I16 *status, const void *textlenp);

void DBCALL3K dbexplain(const HP3K_I16 *status);
void DBCALL3K dberror(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K dbauth(const void *base, const void *pswd, HP3K_I16 *status);
void DBCALL3K dblogon(const void *base, const void *pswd, HP3K_I16 *status);

void DBCALL3K dbversion(void *buffer, int buflen);
void DBCALL3K dbtpiinfo(const void *base, const void *qualifier, const HP3K_I16 *modep,
                     HP3K_I16 *status, void *buffer);

/*
   In order to be able to catch all function calls w/o making
   dld stunts, the same functions are available with a leading
   underscore which implement the functionality.
*/

#if !defined(HP3K_INTERNAL_H) && defined(__HP_cc)
#pragma HP_DEFINED_EXTERNAL _dbbegin,_dbclose,_dbcontrol,_dbdelete,_dbend 
#pragma HP_DEFINED_EXTERNAL _dberror,_dbexplain,_dbfind,_dbget,_dbinfo 
#pragma HP_DEFINED_EXTERNAL _dblock,_dbmemo,_dbopen,_dbput,_dbunlock 
#pragma HP_DEFINED_EXTERNAL _dbupdate,_dbxbegin,_dbxend,_dbxundo 
#pragma HP_DEFINED_EXTERNAL _dbauth,_dblogon,_dbversion,_dbtpiinfo
#endif

void DBCALL3K _dbopen(void *base, const void *pswd, const void *modep,
                  void *status);
void DBCALL3K _dbclose(void *base, const void *dset, const void *modep,
                   void *status);

void DBCALL3K _dbcontrol(const void *base, const void *qualifier,
                     const void *modep, void *status);
void DBCALL3K _dbinfo(const void *base, const void *qualifier, const void *modep,
                  void *status, void *buffer);

void DBCALL3K _dbput(const void *base, const void *dset, const void *modep,
                 void *status, const void *list, void *buffer);
void DBCALL3K _dbdelete(const void *base, const void *dset, const void *modep,
                    void *status);
void DBCALL3K _dbupdate(const void *base, const void *dset, const void *modep,
                    void *status, const void *list, const void *buffer);
void DBCALL3K _dbget(const void *base, const void *dset, const void *modep,
                 void *status, const void *list, void *buffer,
                 const void *argument);
void DBCALL3K _dbfind(const void *base, const void *dset, const void *modep,
                  void *status, const void *item, const void *argument);

void DBCALL3K _dblock(const void *base, const void *qualifier, const void *modep,
                  void *status);
void DBCALL3K _dbunlock(const void *base, const void *qualifier, const void *modep,
                    void *status);

void DBCALL3K _dbbegin(const void *base, const void *text, const void *modep,
                   void *status, const void *textlenp);
void DBCALL3K _dbend(const void *base, const void *text, const void *modep,
                 void *status, const void *textlenp);
void DBCALL3K _dbmemo(const void *base, const void *text, const void *modep,
                  void *status, const void *textlenp);

void DBCALL3K _dbxbegin(const void *base, const void *text, const void *modep,
                    void *status, const void *textlenp);
void DBCALL3K _dbxend(const void *base, const void *text, const void *modep,
                  void *status, const void *textlenp);
void DBCALL3K _dbxundo(const void *base, const void *text, const void *modep,
                   void *status, const void *textlenp);

void DBCALL3K _dbexplain(const void *status);
void DBCALL3K _dberror(const void *status, void *buffer, void *textlenp);
void DBCALL3K _dbauth(const void *base, const void *pswd, void *status);
void DBCALL3K _dblogon(const void *base, const void *pswd, void *status);

void DBCALL3K _dbversion(void *buffer, int buflen);
void DBCALL3K _dbtpiinfo(const void *base, const void *qualifier, const void *modep,
                     void *status, void *buffer);

/*
   Translate upc IMAGE procedure names to lwc symbols.
   Intrinsics are not not case sensitive but mixed case symbols 
   are not handled for now.
*/

#define DBBEGIN dbbegin
#define DBCLOSE dbclose
#define DBCONTROL dbcontrol
#define DBDELETE dbdelete
#define DBEND dbend
#define DBERROR dberror
#define DBEXPLAIN dbexplain
#define DBFIND dbfind
#define DBGET dbget
#define DBINFO dbinfo
#define DBLOCK dblock
#define DBMEMO dbmemo
#define DBOPEN dbopen
#define DBPUT dbput
#define DBUNLOCK dbunlock
#define DBUPDATE dbupdate
#define DBXBEGIN dbxbegin
#define DBXEND dbxend
#define DBXUNDO dbxundo
#define DBAUTH dbauth
#define DBLOGON dblogon
#define DBVERSION dbversion
#define DBTPIINFO dbtpiinfo

#if defined(__cplusplus)
}
#endif

#endif /* IMAGE3K_H */

==> PE70-0411080-linux-glibc2.2.tar.gz: include/image3k.h <==
/* -----------------------------------------------------------------------

   (C) Copyright Marxmeier Software AG 1998-2004. 
   All rights reserved.

   Project:  HP3K API
   File:     image3k.h
   Function: IMAGE3K API
   $Id: image3k.h,v 23.27 2004/11/08 14:10:40 mike Exp $

   If IMAGE3K_STRICT_PROTOTYPES is defined than stricter function
   prototypes are provided (short * vs. void * arguments).

   Edit history:
   15.09.1998, mm  - fixed prototypes
   08.04.1999, mm  - stub prototypes
   14.04.1999, mm  - lwc entry points
   06.02.2002, mm  - add DBTPIINFO
   08.05.2002, mm  - fixed DBERROR prototype
                     added DBLOGON as alias for DBAUTH
   13.09.2002, rhg - DBCALL -> DBCALL3K
   12.07.2003, mm  - added DBVERSION inrinsic
   31.07.2003, mm  - fixed typos in comments
   12.02.2004, mm  - added DBMAINT intrinsic
   02.06.2004, mm  - added DBCALL, DBSTATUS2 intrinsics
   03.06.2004, mm  - added DBSTATUS intrinsic
   15.10.2004, mm  - commend out #pragma HP_DEFINED_EXTERNAL for now
                     as this may cause a problem if the image3k lib
		     is linked statically (archive)

----------------------------------------------------------------------- */

#ifndef IMAGE3K_H
#define IMAGE3K_H

#if defined(__cplusplus)
extern "C" {
#endif

/*
   define ELOQUENCE symbol so EQ aware programs can #ifdef
   some stuff ...
*/
#define ELOQUENCE 1


/*
   HP3K intrinsic numbers.
   Not sure if they need to be public, however it should not hurt
   since the symbols are rather unlikely to be used otherwise
*/
enum hp3k_Intrinsic_ID {
   DBOPEN_INTRINSIC_ID    = 401,
   DBINFO_INTRINSIC_ID    = 402,
   DBCLOSE_INTRINSIC_ID   = 403,
   DBFIND_INTRINSIC_ID    = 404,
   DBGET_INTRINSIC_ID     = 405,
   DBUPDATE_INTRINSIC_ID  = 406,
   DBPUT_INTRINSIC_ID     = 407,
   DBDELETE_INTRINSIC_ID  = 408,
   DBLOCK_INTRINSIC_ID    = 409,
   DBUNLOCK_INTRINSIC_ID  = 410,
   DBCONTROL_INTRINSIC_ID = 411,
   DBBEGIN_INTRINSIC_ID   = 412,
   DBEND_INTRINSIC_ID     = 413,
   DBMEMO_INTRINSIC_ID    = 414,
   DBMAINT_INTRINSIC_ID   = 415,
   DBEXPLAIN_INTRINSIC_ID = 418,
   DBERROR_INTRINSIC_ID   = 419,
   DBXBEGIN_INTRINSIC_ID  = 420,
   DBXEND_INTRINSIC_ID    = 421,
   DBXUNDO_INTRINSIC_ID   = 422,
   DBTPIINFO_INTRINSIC_ID = 480
};


/*
   Win32 API calling convention
   default: __stdcall, use -DDBCALL3K=__cdecl compiler directive otherwise
*/
#ifdef _WIN32
#ifndef DBCALL3K
#define DBCALL3K __stdcall
#endif
#else
#ifdef DBCALL3K
#undef DBCALL3K
#endif
#define DBCALL3K /**/
#endif


/*
   IMAGE3K API prototypes
*/

#ifdef IMAGE3K_STRICT_PROTOTYPES
#define HP3K_I16 short
#else
#define HP3K_I16 void
#endif

#if 0 && !defined(HP3K_INTERNAL_H) && defined(__HP_cc)
#pragma HP_DEFINED_EXTERNAL dbbegin,dbclose,dbcontrol,dbdelete,dbend 
#pragma HP_DEFINED_EXTERNAL dberror,dbexplain,dbfind,dbget,dbinfo 
#pragma HP_DEFINED_EXTERNAL dblock,dbmemo,dbopen,dbput,dbunlock 
#pragma HP_DEFINED_EXTERNAL dbupdate,dbxbegin,dbxend,dbxundo 
#pragma HP_DEFINED_EXTERNAL dbauth,dblogon,dbversion,dbtpiinfo
#pragma HP_DEFINED_EXTERNAL dbmaint,dbcall,dbstatus,dbstatus2
#pragma HP_DEFINED_EXTERNAL nmdbstatus,nmdbstatus2
#endif

void DBCALL3K dbopen(void *base, const void *pswd, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL3K dbclose(void *base, const void *dset, const HP3K_I16 *modep,
                   HP3K_I16 *status);

void DBCALL3K dbcontrol(const void *base, const void *qualifier,
                     const HP3K_I16 *modep, HP3K_I16 *status);
void DBCALL3K dbinfo(const void *base, const void *qualifier, const HP3K_I16 *modep,
                  HP3K_I16 *status, void *buffer);

void DBCALL3K dbput(const void *base, const void *dset, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *list, void *buffer);
void DBCALL3K dbdelete(const void *base, const void *dset, const HP3K_I16 *modep,
                    HP3K_I16 *status);
void DBCALL3K dbupdate(const void *base, const void *dset, const HP3K_I16 *modep,
                    HP3K_I16 *status, const void *list, const void *buffer);
void DBCALL3K dbget(const void *base, const void *dset, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *list, void *buffer,
                 const void *argument);
void DBCALL3K dbfind(const void *base, const void *dset, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *item, const void *argument);

void DBCALL3K dblock(const void *base, const void *qualifier, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL3K dbunlock(const void *base, const void *qualifier, const HP3K_I16 *modep,
                    HP3K_I16 *status);

void DBCALL3K dbbegin(const void *base, const void *text, const HP3K_I16 *modep,
                   HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbend(const void *base, const void *text, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbmemo(const void *base, const void *text, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *textlenp);

void DBCALL3K dbxbegin(const void *base, const void *text, const HP3K_I16 *modep,
                    HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbxend(const void *base, const void *text, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *textlenp);
void DBCALL3K dbxundo(const void *base, const void *text, const HP3K_I16 *modep,
                   HP3K_I16 *status, const void *textlenp);

void DBCALL3K dbexplain(const HP3K_I16 *status);
void DBCALL3K dberror(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K dbauth(const void *base, const void *pswd, HP3K_I16 *status);
void DBCALL3K dblogon(const void *base, const void *pswd, HP3K_I16 *status);

void DBCALL3K dbversion(void *buffer, int buflen);
void DBCALL3K dbtpiinfo(const void *base, const void *qualifier, const HP3K_I16 *modep,
                  HP3K_I16 *status, void *buffer);

void DBCALL3K dbmaint(void *base, const void *pswd, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL3K dbcall(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K dbstatus(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K dbstatus2(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K nmdbstatus(const HP3K_I16 *status, void *buffer, 
                  HP3K_I16 *textlenp, int is_nm);
void DBCALL3K nmdbstatus2(const HP3K_I16 *status, void *buffer, 
                  HP3K_I16 *textlenp);


/*
   In order to be able to catch all function calls w/o making
   dld stunts, the same functions are available with a leading
   underscore which implement the functionality.
*/

#if 0 && !defined(HP3K_INTERNAL_H) && defined(__HP_cc)
#pragma HP_DEFINED_EXTERNAL _dbbegin,_dbclose,_dbcontrol,_dbdelete,_dbend 
#pragma HP_DEFINED_EXTERNAL _dberror,_dbexplain,_dbfind,_dbget,_dbinfo 
#pragma HP_DEFINED_EXTERNAL _dblock,_dbmemo,_dbopen,_dbput,_dbunlock 
#pragma HP_DEFINED_EXTERNAL _dbupdate,_dbxbegin,_dbxend,_dbxundo 
#pragma HP_DEFINED_EXTERNAL _dbauth,_dblogon,_dbversion,_dbtpiinfo
#pragma HP_DEFINED_EXTERNAL _dbmaint,_dbcall,_dbstatus,_dbstatus2
#pragma HP_DEFINED_EXTERNAL _nmdbstatus,_nmdbstatus2
#endif

void DBCALL3K _dbopen(void *base, const void *pswd, const void *modep,
                  void *status);
void DBCALL3K _dbclose(void *base, const void *dset, const void *modep,
                   void *status);

void DBCALL3K _dbcontrol(const void *base, const void *qualifier,
                     const void *modep, void *status);
void DBCALL3K _dbinfo(const void *base, const void *qualifier, const void *modep,
                  void *status, void *buffer);

void DBCALL3K _dbput(const void *base, const void *dset, const void *modep,
                 void *status, const void *list, void *buffer);
void DBCALL3K _dbdelete(const void *base, const void *dset, const void *modep,
                    void *status);
void DBCALL3K _dbupdate(const void *base, const void *dset, const void *modep,
                    void *status, const void *list, const void *buffer);
void DBCALL3K _dbget(const void *base, const void *dset, const void *modep,
                 void *status, const void *list, void *buffer,
                 const void *argument);
void DBCALL3K _dbfind(const void *base, const void *dset, const void *modep,
                  void *status, const void *item, const void *argument);

void DBCALL3K _dblock(const void *base, const void *qualifier, const void *modep,
                  void *status);
void DBCALL3K _dbunlock(const void *base, const void *qualifier, const void *modep,
                    void *status);

void DBCALL3K _dbbegin(const void *base, const void *text, const void *modep,
                   void *status, const void *textlenp);
void DBCALL3K _dbend(const void *base, const void *text, const void *modep,
                 void *status, const void *textlenp);
void DBCALL3K _dbmemo(const void *base, const void *text, const void *modep,
                  void *status, const void *textlenp);

void DBCALL3K _dbxbegin(const void *base, const void *text, const void *modep,
                    void *status, const void *textlenp);
void DBCALL3K _dbxend(const void *base, const void *text, const void *modep,
                  void *status, const void *textlenp);
void DBCALL3K _dbxundo(const void *base, const void *text, const void *modep,
                   void *status, const void *textlenp);

void DBCALL3K _dbexplain(const void *status);
void DBCALL3K _dberror(const void *status, void *buffer, void *textlenp);
void DBCALL3K _dbauth(const void *base, const void *pswd, void *status);
void DBCALL3K _dblogon(const void *base, const void *pswd, void *status);

void DBCALL3K _dbversion(void *buffer, int buflen);
void DBCALL3K _dbtpiinfo(const void *base, const void *qualifier, const void *modep,
                     void *status, void *buffer);

void DBCALL3K _dbmaint(void *base, const void *pswd, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL3K _dbcall(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K _dbstatus(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K _dbstatus2(const HP3K_I16 *status, void *buffer, HP3K_I16 *textlenp);
void DBCALL3K _nmdbstatus(const HP3K_I16 *status, void *buffer, 
                  HP3K_I16 *textlenp, int is_nm);
void DBCALL3K _nmdbstatus2(const HP3K_I16 *status, void *buffer, 
                  HP3K_I16 *textlenp);


/*
   Translate upc IMAGE procedure names to lwc symbols.
   Intrinsics are not case sensitive but mixed case symbols 
   are not handled for now.
*/

#define DBBEGIN dbbegin
#define DBCLOSE dbclose
#define DBCONTROL dbcontrol
#define DBDELETE dbdelete
#define DBEND dbend
#define DBERROR dberror
#define DBEXPLAIN dbexplain
#define DBFIND dbfind
#define DBGET dbget
#define DBINFO dbinfo
#define DBLOCK dblock
#define DBMEMO dbmemo
#define DBOPEN dbopen
#define DBPUT dbput
#define DBUNLOCK dbunlock
#define DBUPDATE dbupdate
#define DBXBEGIN dbxbegin
#define DBXEND dbxend
#define DBXUNDO dbxundo
#define DBAUTH dbauth
#define DBLOGON dblogon
#define DBVERSION dbversion
#define DBTPIINFO dbtpiinfo
#define DBMAINT dbmaint
#if !defined(DBCALL)
/* FIXME: This use of DBCALL currently conflicts with the eloqdb 
   DBCALL #define that is used on WIN32 to specify the calling 
   convention. So we do not #define DBCALL here if the eloqdb.h
   was included before ... */
#define DBCALL dbcall
#endif
#define DBSTATUS dbstatus
#define DBSTATUS2 dbstatus2

#if defined(__cplusplus)
}
#endif

#endif /* IMAGE3K_H */
